@@ -33,7 +33,7 @@ eel_gnome_date_edit_get_date_as_string (GnomeDateEdit *dateedit)
 {
 	time_t selected_time;
 
-	selected_time = gnome_date_edit_get_date (dateedit);
+	selected_time = gnome_date_edit_get_time (dateedit);
 	if (selected_time < 0) {
 		return NULL;
 	}
